--- openflow-2012-03-27.h	2015-07-23 09:54:17.144479362 -0700
+++ openflow-2012-04-03.h	2015-07-23 09:54:17.148479362 -0700
@@ -1682,18 +1682,18 @@
     OFPMP_GROUP_FEATURES = 8,
 
     /* Meter statistics.
      * The request body is struct ofp_meter_stats_requests.
      * The reply body is struct ofp_meter_stats. */
     OFPMP_METER = 9,
 
     /* Meter configuration.
      * The request body is struct ofp_meter_stats_requests.
      * The reply body is struct ofp_meter_config_stats. */
     OFPMP_METER_CONFIG = 10,
 
     /* Meter features.
      * The request body is empty.
-     * The reply body is struct ofp_meter_features_stats. */
+     * The reply body is struct ofp_meter_features. */
     OFPMP_METER_FEATURES = 11,
 
     /* Table features.
@@ -2058,12 +2058,12 @@
 };
 OFP_ASSERT(sizeof(struct ofp_group_features) == 40);
 
-/* Body of OFPMP_METER request. */
-struct ofp_meter_stats_request {
+/* Body of OFPMP_METER and OFPMP_METER_CONFIG requests. */
+struct ofp_meter_multipart_request {
     uint32_t meter_id;       /* Meter instance, or OFPM_ALL. */
     uint8_t pad[4];          /* Align to 64 bits. */
 };
-OFP_ASSERT(sizeof(struct ofp_meter_stats_request) == 8);
+OFP_ASSERT(sizeof(struct ofp_meter_multipart_request) == 8);
 
 /* Statistics for each meter band */
 struct ofp_meter_band_stats {
@@ -1682,18 +1682,18 @@
 
     /* Meter statistics.
-     * The request body is struct ofp_meter_stats_requests.
-     * The reply body is struct ofp_meter_stats. */
+     * The request body is struct ofp_meter_multipart_requests.
+     * The reply body is an array of struct ofp_meter_stats. */
     OFPMP_METER = 9,
 
@@ -1682,18 +1682,18 @@
 
     /* Meter configuration.
-     * The request body is struct ofp_meter_stats_requests.
-     * The reply body is struct ofp_meter_config_stats. */
+     * The request body is struct ofp_meter_multipart_requests.
+     * The reply body is an array of struct ofp_meter_config. */
     OFPMP_METER_CONFIG = 10,
 
